==> haskell-swagger2-2.8.10-89.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 swagger2
version:              2.8.10
visibility:           public
id:                   swagger2-2.8.10-Fm97ws82YhV4MJk54EC85t
key:                  swagger2-2.8.10-Fm97ws82YhV4MJk54EC85t
license:              BSD-3-Clause
copyright:            (c) 2015-2016, GetShopTV
maintainer:           nickolay@getshoptv.com
author:               Nickolay Kudasov
homepage:             https://github.com/GetShopTV/swagger2
synopsis:             Swagger 2.0 data model
description:
    This library is intended to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.

    The original Swagger 2.0 specification is available at http://swagger.io/specification/.

category:             Web, Swagger
abi:                  ad9e9ec18018d493b45780c7431c9508
exposed:              True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.Optics
    Data.Swagger.ParamSchema Data.Swagger.Schema
    Data.Swagger.Schema.Generator Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions

import-dirs:          /usr/lib/ghc-9.6.6/site-local/swagger2-2.8.10
library-dirs:         /usr/lib/ghc-9.6.6/site-local/swagger2-2.8.10
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/swagger2-2.8.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-swagger2
hs-libraries:         HSswagger2-2.8.10-Fm97ws82YhV4MJk54EC85t
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    aeson-pretty-0.8.10-CQgtmRgYKKmDAUdx88Og8E base-4.18.2.1
    base-compat-batteries-0.14.1-lgVr2peCDw5qXG4VLbklv
    bytestring-0.11.5.3 containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    generics-sop-0.5.1.3-2A8djQkaEZB9fJBOGd7gV
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    http-media-0.8.1.1-IVN9WTR9Vpq260gzanGeUu
    insert-ordered-containers-0.2.5.3-Dukg6b3O0oB3rj9hcuMQqG
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM mtl-2.3.1
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    optics-core-0.4.1.1-3uSkdT24fvM6dyJIU7nYms
    optics-th-0.4.1-Ekr5DHYNwQR71A78UrbGmv
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    uuid-types-1.0.6-58FfeLal0FhHrTZjsfHNqD
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html:         /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-swagger2-2.8.10-90-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 swagger2
version:              2.8.10
visibility:           public
id:                   swagger2-2.8.10-9b9lcZWIuur8JMkaDITY9o
key:                  swagger2-2.8.10-9b9lcZWIuur8JMkaDITY9o
license:              BSD-3-Clause
copyright:            (c) 2015-2016, GetShopTV
maintainer:           nickolay@getshoptv.com
author:               Nickolay Kudasov
homepage:             https://github.com/GetShopTV/swagger2
synopsis:             Swagger 2.0 data model
description:
    This library is intended to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.

    The original Swagger 2.0 specification is available at http://swagger.io/specification/.

category:             Web, Swagger
abi:                  3ef400a43160580fac413422688e221e
exposed:              True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.Optics
    Data.Swagger.ParamSchema Data.Swagger.Schema
    Data.Swagger.Schema.Generator Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions

import-dirs:          /usr/lib/ghc-9.6.6/site-local/swagger2-2.8.10
library-dirs:         /usr/lib/ghc-9.6.6/site-local/swagger2-2.8.10
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/swagger2-2.8.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-swagger2
hs-libraries:         HSswagger2-2.8.10-9b9lcZWIuur8JMkaDITY9o
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    aeson-pretty-0.8.10-BjxB783FV8e8YPhrNbMs4J base-4.18.2.1
    base-compat-batteries-0.14.1-7XhCMBTAbUaB4cukby3R0h
    bytestring-0.11.5.3 containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    generics-sop-0.5.1.3-2A8djQkaEZB9fJBOGd7gV
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    http-media-0.8.1.1-ESBCw4Dvl5R7GQFVDBq0Rc
    insert-ordered-containers-0.2.5.3-F3ZWofUloJ3FcOrvJbOGyb
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB mtl-2.3.1
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    optics-core-0.4.1.1-3uSkdT24fvM6dyJIU7nYms
    optics-th-0.4.1-Ekr5DHYNwQR71A78UrbGmv
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    uuid-types-1.0.6-21TzNsexUnW19QIZkyQGNe
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html:         /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
